jactorch.functional.quantization
================================

.. automodule:: jactorch.functional.quantization

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      quantize
      randomized_quantize
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: quantize

.. autofunction:: randomized_quantize


